#
# spec file for package opal
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_with ffmpeg
%bcond_with x264
%bcond_with capi4linux

Name:           opal
%if %{with capi4linux}
BuildRequires:  capi4linux-devel
%endif
BuildRequires:  gcc-c++
BuildRequires:  ilbc
BuildRequires:  libcelt-devel
BuildRequires:  libgsm-devel
%if %{with ffmpeg}
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavutil)
%endif
BuildRequires:  libopenssl-devel
BuildRequires:  libpt-devel >= 2.10.1
BuildRequires:  libsamplerate-devel
BuildRequires:  libstdc++-devel
BuildRequires:  libtheora-devel
%if %{with x264}
BuildRequires:  libx264-devel
%endif
BuildRequires:  pkg-config
BuildRequires:  speex-devel
BuildRequires:  swig
# FIXME: ZRTP is implemented through libzrtp. Its webpage says it's AGPL, but I
# was unable to find a copy with that license. srtp is in Contrib, it should be
# moved back to support it here.
BuildRequires:  spandsp-devel
Summary:        Open Phone Abstraction Library
License:        MPL-1.0
Group:          System/Libraries
Url:            http://www.opalvoip.org/
Version:        3.10.10
Release:        150600.20.2
# FIXME: we should probably list all plugins in %%files to make sure we don't lose some when updating the package.
%define _version 3_10_10
Source0:        http://download.gnome.org/sources/opal/3.10/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM opal-system-libgsm.patch vuntz@novell.com -- Fix detection of system libgsm
Patch1:         opal-system-libgsm.patch
# PATCH-FIX-UPSTREAM opal-fix-ambiguous.patch vuntz@novell.com -- Fix ambiguous code
Patch2:         opal-fix-ambiguous.patch
# PATCH-FIX-UPSTREAM opal-use-pkgconfig-for-PTLib.patch zaitor@opensuse.org  -- Use pkgconfig for PTLib, taken from upstream svn, fixes build.
Patch4:         opal-use-pkgconfig-for-PTLib.patch 
# PATCH-FIX-UPSTREAM bmwiedemann https://sourceforge.net/p/opalvoip/patches/333/
Patch5:         reproducible.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Open Phone Abstraction Library, implementation of the ITU H.323
teleconferencing protocol, and successor of the openh323 library. It
supports the H.323 protocol as well as SIP and IAX2.



%package -n lib%{name}%{_version}

Summary:        Open Phone Abstraction Library
Group:          System/Libraries

%description -n lib%{name}%{_version}
Open Phone Abstraction Library, implementation of the ITU H.323
teleconferencing protocol, and successor of the openh323 library. It
supports the H.323 protocol as well as SIP and IAX2.



%package -n lib%{name}-devel

Summary:        Development package for %{name}
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{_version} = %{version}
Requires:       libpt-devel
# opal-devel was last used in openSUSE 11.3
Provides:       opal-devel = %{version}
Obsoletes:      opal-devel < %{version}

%description -n lib%{name}-devel
Static libraries and header files for development with opal.



%prep
%setup -q
%patch1 -p1
%patch2 -p1
%patch4 -p1
%patch5 -p1
# this subdir contains GPL - to avoid license issues delete it before build
rm -rf plugins/LID/VPB

%build
%if %{with ffmpeg} || %{with x264}
cd plugins
autoreconf -fi
cd ..
%endif
# Can support Voicetronix vpb
export CXXFLAGS="%optflags -fvisibility-inlines-hidden -std=gnu++98"
%configure --disable-static \
	--enable-sbc \
%if %{with capi4linux}
	--enable-capi \
%endif
	--disable-ixj

make %{?_smp_mflags} VERBOSE=1

%install
%makeinstall
rm -f %{buildroot}%{_libdir}/lib%{name}_s.a

%post -n lib%{name}%{_version} -p /sbin/ldconfig

%postun -n lib%{name}%{_version} -p /sbin/ldconfig

%clean
rm -rf $RPM_BUILD_ROOT

%files -n lib%{name}%{_version}
%defattr(-,root,root)
%doc  mpl-1.0.htm
%dir %{_libdir}/%{name}-%{version}/ 
%dir %{_libdir}/%{name}-%{version}/codecs
%dir %{_libdir}/%{name}-%{version}/codecs/audio
%dir %{_libdir}/%{name}-%{version}/codecs/video
%dir %{_libdir}/%{name}-%{version}/fax
%{_libdir}/libopal.so.%{version}
%{_libdir}/%{name}-%{version}/codecs/audio/celt_ptplugin.so
%{_libdir}/%{name}-%{version}/codecs/audio/g7221_ptplugin.so
%{_libdir}/%{name}-%{version}/codecs/audio/g7222_ptplugin.so
%{_libdir}/%{name}-%{version}/codecs/audio/g722_ptplugin.so
%{_libdir}/%{name}-%{version}/codecs/audio/g726_ptplugin.so
%{_libdir}/%{name}-%{version}/codecs/audio/gsm0610_ptplugin.so
%{_libdir}/%{name}-%{version}/codecs/audio/gsmamrcodec_ptplugin.so
%{_libdir}/%{name}-%{version}/codecs/audio/iLBC_ptplugin.so
%{_libdir}/%{name}-%{version}/codecs/audio/ima_adpcm_ptplugin.so
%{_libdir}/%{name}-%{version}/codecs/audio/lpc10_ptplugin.so
%{_libdir}/%{name}-%{version}/codecs/audio/silk_ptplugin.so
%{_libdir}/%{name}-%{version}/codecs/audio/speex_ptplugin.so
%{_libdir}/%{name}-%{version}/codecs/video/h261_vic_ptplugin.so
%{_libdir}/%{name}-%{version}/codecs/video/theora_ptplugin.so
%{_libdir}/%{name}-%{version}/fax/spandsp_ptplugin.so

%files -n lib%{name}-devel
%defattr(-,root,root)
%{_includedir}/%{name}/
%{_libdir}/libopal.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Thu Jun 28 2018 dimstar@opensuse.org
- Pass --disable-ixj to configure instead of --enable-ixj: Linux
  4.17 no longer brings the public telephony headers and future
  versions of opal (starting with 3.14) would not support xJACK
  neither (addresses boo#1098764).
* Tue Sep 26 2017 zaitor@opensuse.org
- No longer build capi4linux support on openSUSE, but leave in
  place becond, so it will be easy for users that wants to build
  this support on their own.
* Fri Aug 11 2017 fcrozat@suse.com
- Don't build capi4linux support on SLE15 (FATE#323348).
* Mon May 29 2017 bwiedemann@suse.com
- Add reproducible.patch to sort input files to make build reproducible
  (boo#1041090)
* Thu May 26 2016 dimstar@opensuse.org
- Build opal using -std=gnu++98. It's old code.
* Sat Apr 16 2016 olaf@aepfle.de
- Use pkgconfig instead of libffmpeg-devel
* Fri Jan 30 2015 crrodriguez@opensuse.org
- Build C++ code with -fvisibility-inlines-hidden shrinks
  the exported symbol table of libopal from 36945 to
  23124.
* Tue Feb 26 2013 dimstar@opensuse.org
- Update to version 3.10.10:
  + Several fixes for H.323.
  + Fix subscribing/unsubscribing when enabling and disabling SIP
    accounts.
  + Bug fixes.
- Drop opal-server-flood.patch: fixed upstream.
* Thu Dec 13 2012 idonmez@suse.com
- Add opal-server-flood.patch: Fix server flood in some configurations
  Upstream r28644 and r28650 also bgo#690144
* Mon Dec  3 2012 dimstar@opensuse.org
- Update to version 3.10.9:
  + Various SIP interoperability fixes.
  + Added SIP Service-Route header support (RFC 3608).
  + Various SIP/SIMPLE presence related fixes.
  + Fixed registration to broken registrars.
  + Unregister all accounts on quit.
  + Publish offline presence on quit.
  + Refresh NAT bindings with SIP OPTIONS requests.
  + Support for DNS SRV caching.
* Mon Aug 27 2012 dimstar@opensuse.org
- Update to version 3.10.7:
  + Fixed SIP authentication so cannot ever get into continuous
    retry of bad credentials.
  + Fixed OpenPhone status indication of invalid credentials on
    register/subscribe.
  + Fixed race condition searching for H.323 connections.
  + Remove obsolete stack align hack for ffmpeg
- Changes from version 3.10.6:
  + Fix H.323 using H.263+ only.
  + Fixed ordering of media formats from H.245 TCS, so now
    correctly opens preferred codec indicated by remote.
  + Only to NAT refresh for SIP REGISTER and SUBSCRIBE handlers.
  + Increase default RTP payload size.
  + Removed very old NetMeeting compatible H.261 media formats as
    they now seem to cause other endpoints issues.
  + Fixed H.323 transmit channel only using target bit rate not max
    bit rate.
  + Fixed shut down of RTP session when using STUN.
  + Fixed handling of SIP 491 Request Pending response.
  + Only use re-INVITE to resolve the multiple codec in response
    SDP when in 2xx response, not 183's etc.
  + Correctly handled INVITE with SDP when call on hold.
  + Include sessionID in H.323 OLC Ack for "standard" session ID
    numbers (audio/video) even though not strictly necessary.
  + Fixed H.323 bandwidth control on individual channel.
  + Several bug fixes and other code changes.
- Drop opal-fix-SILK-test.patch: fixed upstream.
* Fri May 18 2012 zaitor@opensuse.org
- Update to version 3.10.5:
  + Numerous changes, look in ChangeLog-opal-v3_10_5.txt
- Drop opal-pkg_config.patch, opal-missing_links.patch,
  opal-new-celt.patch,opal-codecs.patch, opal-3.4.2.diff,
  opal-x264.patch and opal-3.6.6-non_void.patch, fixed upstream.
- Rebased opal-fix-ambiguous.patch, opal-system-libgsm.patch
- Add opal-use-pkgconfig-for-PTLib.patch and
  opal-fix-SILK-test.patch
- Explicitly list all .so files so nothing is accidently lost on
  future updates.
- Stop using obs service to download source, since factory is
  moving away from it.
* Tue Dec 14 2010 vuntz@opensuse.org
- Add opal-new-celt.patch to fix build with celt 0.9, on openSUSE
  11.4 and later. The patch is taken from PLD Linux.
* Thu Oct  7 2010 reddwarf@opensuse.org
- Add opal-missing_links.patch:
  + Ensure correct openSSL version is used
  + Link against libraries that incorrect command order and
    openSUSE's --as-needed removed without notice
  + Make CAPI plugin able to load
  + Enable IxJ plugin installation
* Wed Aug 11 2010 reddwarf@opensuse.org
- Fix build when ffmpeg and x264 are enabled.
- Add opal-x264.patch: partial fix for H.264.
* Wed Jul 28 2010 reddwarf@opensuse.org
- Update to version 3.6.8:
  + Fixed possible NULL pointer access if get multiple NOTIFY
    messages on a REFER.
  + Fixed Restricted Cone and Port Restricted Cone NAT varieties to
    correctly send out translated RTP address and port.
  + Improved CELT plugin.
  + IPv6 fixes.
  + Fixed "C" API call transfer command using call forwarding
    mechanism if call not yet connected.
- Changes from version 3.6.7:
  + Fixed correct test handling RFC3261/8.2.2.2 merged requests and
    other "multi-path" received INVITE requests.
  + Fixed possible crash when ending fax call.
  + Fixed locating correct authorisation credentials for INVITE
    when AOR user is different from authorisation ID.
  + Fixed address translation of REGISTER contact fields when STUN
    is not being used, but a fixed translation address is.
  + Fixed authentication issue when can get to SIP server via two
    interfaces.
  + Fixed SIP REFER completion on receiving NOTIFY with id
    parameter.
  + Fixed double authorisation failure leaving SIP handler in the
    wrong state, should move to Unavailable but with no timer to
    retry.
  + Changed authentication failure to be fatal and SIP handler
    removed.
  + Fixed incorrect change to AlertingPhase when have not actually
    got alerting packet.
  + Build fixes.
  + Add nonce to comparison for digest authentication.
  + Added missing timestamp value when using fax -> G.711 mode.
  + Change to only unregister those contact addresses we
    successfully registered, instead of using global '*'.
  + Take the mixer OnWriteAudio() call out of the mutexed zone.
  + Added WAV file open error reason text for recording WAV file.
  + Fixed strange issue with SIP call diversion (302 response) to
    the same endpoint, from some UACs where it reuses the same
    call-id and from-tag.
- Follow SLPP and rename opal-devel to libopal-devel.
- Make H.263/H.263+, H.264 and MPEG4 Part 2 support build
  conditional: add conditional BuildRequires for libffmpeg-devel
  and libx264-devel.
- Change libpt2-devel BuildRequires and Requires in devel package
  to libpt-devel, following renaming there.
- Add ilbc BuildRequires to use system version of iLBC.
- Add libcelt-devel BuildRequires to enable CELT support.
- Add pkg-config and libopenssl-devel BuildRequires.
- Remove hack with Requires on the libpt2 version we were built
  against since this is not needed anymore because we do not mess
  with the soversion anymore.
- Add opal-codecs.patch to fix ffmpeg and x264 runtime detection.
- Add opal-pkg_config.patch: this remove abusive link flags from
  the pkg-config file.
- Update opal-3.6.6-non_void.patch to fix more issues.
- Update opal-system-libgsm.patch to fix detection of GSM system
  library.
- Remove static library.
* Tue Mar  2 2010 ro@suse.de
- fix warning: no return statement in function returning non-void
  to fix build (in CAPI.cxx)
* Tue Oct  6 2009 dimstar@opensuse.org
- Update to version 3.6.6:
  + Fixed failure to increment CSEQ on second INVITE after an
    authorisation request error.
* Sun Sep 13 2009 dimstar@opensuse.org
- Forcibly require the version of libpt2 used at buildtime.
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Sun Jul 19 2009 dominique-obs@leuenberger.net
- Update to version 2.6.4:
  + Bugfix release.
* Tue May 19 2009 dominique-obs@leuenberger.net
- Update to version 3.6.2:
  + Bugfix release.
* Wed Apr 29 2009 vuntz@novell.com
- Update to version 3.6.1:
  + This is a major update of ptlib/opal with the following main
    features:
  - Instant Messaging. Using several different “standards”:
    RFC4975, MSRP, T.140, SIP-IM etc etc.
  - Much improved support for SIP event handling
    (SUBSCRIBE/NOTIFY/PUBLISH) using factories so more event
    packages can be added easily.
  - Support for SIP “dialog” event package.
  - Support for Shared Line Appearance (aka Multiple Line
    Appearance, Bridged Line Appearance or Busy Lamp Field)
  - Significant improvements in IPv6 support
  - Major enhancements to the video rate controller.
  - Removal of the old H.263 ffmpeg plug in and enhancement of
    the H.263-1998 plug it to take its place.
  - H.224 support (H.323 only).
  - SBC audio codec plug in.
  - G.722 audio codec plug in.
  - CELT audio codec plug in.
  - SWIG support for use in other languages, Java first.
  - Much improved multi-platform sample GUI client, OpenPhone.
    Now standard test environment replacing simpleOPAL.
- Update opal-3.4.2.diff: most of it was fixed upstream, a simple
  memset() is left.
- Add opal-system-libgsm.patch to fix detection of system libgsm.
- Add opal-fix-ambiguous.patch to fix some ambiguous code.
- Add capi4linux-devel, libgsm-devel, libsamplerate-devel,
  libtheora-devel, swig BuildRequires.
- Pass --enable-zrtp, --enable-sbc, --enable-ixj, --enable-capi to
  configure.
- Use makeinstall.
* Thu Nov  6 2008 kkeil@suse.de
- do not create include/opal/buildopts.h.in from scratch
  This caused configuration errors in ekiga (bnc#440869)
* Sun Oct 26 2008 kkeil@suse.de
- update to bugfix release 3.4.2
  * Fix system speex detection
  * Simplify setting of LIBS and CFLAGS
  * Fix H.261 on solaris
  * Fixed line endings
  * Fixed inclusion of RFC2833 (DTMF) capability in H.323 calls
  * Fixed bug in "C" API when message callback function is used
  * Fixed SIP INVITE loop detection, forked INVITE request arriving
    over multiple paths
  * Removed last vestiges of numerical media types
  * Fixed release of the call when audio channel ends
  * Fix static x264 compilation
  * Fixed several SIP compliance issues
  * Fixed incorrect LID caller line ID field being used for display
    name
  * Adapt to libavcodec's new interface 52
  * Also trigger the presence callback when the NOTIFY body is empty
  * Update wxWidgets version in OpenPhone ReadMe.txt instructions
  * Fixed interoperability issues with Cisco call manager, working
    around an annoying bug with the Cisco
  * Fixed OpenPhone about box
  * Fix H.264 flags to request I-frames thanks to Mauro Davi
  * Improved LID logging so indicates reason why line was not
    selected
  * Added some H.261 and H.263 annexes to H.263
  * Added OpenPhone menu and dialog to do transmit video control, in
    particular, changing the target bit rate
  * Fixed issue with propagating changes to media options to
    transcoders and streams in a patch
  * Added video frame rate to OpenPhone statistics
  * Fixed incorrect line type (pots/pstn) selection
  * Changed ring detect so increments count on "rising edge" of ring
    cadence
  * Fixed numerous retries using the same authentication credentials
  * Fixed listening interfaces port when mapped by STUN being
    included as first interface in the listener list
  * Fixed problem in forked INVITE
  * Change error for a SIP BYE on a call already destroyed
  * Added user defined tone in LIDs
  * Deal with endpoints that use spaces and ; as seperators
  * Fixed being able to specify socket re-use address mode
  * Fix second case where simpleopal tries to use SDL for both output
    and preview video
  * Fixed race condition where if reply from SIP server is so fast
    that it gets in before the second PDU of a forked query
  * Fixed printing of new LID tone
  * Fixed missing party B address when originating PSTN call
* Mon Oct 13 2008 kkeil@suse.de
- update to version 3.4.1 needed by ekiga 3.0 (bnc#428117)
  * for detailed changes see Change* in the package
* Fri Oct  5 2007 kkeil@suse.de
- readd opal-C-fix.diff it was only partly upstream
* Wed Sep 19 2007 mauro@suse.de
- Update to 2.2.11 to make ekiga (for gnome 2.20) happy.
* Mon Jul  9 2007 kkeil@suse.de
- change library name to make rpmlint happy (#290347)
* Sat May  5 2007 kkeil@suse.de
- removed additional "-fstack-protector" from OPTCCFLAGS it is
  already in RPM_OPT_FLAGS
* Tue Apr 24 2007 maw@suse.de
- Update to version 2.2.8
  - bugfix release
* Wed Feb 14 2007 kkeil@suse.de
- downgrade to stable 2.2.5 version
* Mon Oct 23 2006 kkeil@suse.de
- clean up undefined C code (#213075)
* Wed Oct 11 2006 sbrabec@suse.cz
- Fixed invalid SIP header response quotation. Fixes problems with
  registration on certain servers.
* Fri Sep 29 2006 kkeil@suse.de
- fix double response frames (patch from sbrabec@suse.cz)
- updates from current stable to handle reinvites better
* Wed Sep  6 2006 kkeil@suse.de
- delete optional GPL file before build to avoid license issues
  (#202829)
* Thu Aug 10 2006 sbrabec@suse.cz
- Reduced BuildRequires.
* Thu Aug 10 2006 kkeil@suse.de
- first version (2.3.1) for autobuild
